colour.colorimetry.dataset.lefs Module — Colour 0.3.0 documentation

# colour.colorimetry.dataset.lefs Module

## Luminous Efficiency Functions Spectral Power Distributions

Defines various luminous efficiency functions involved in spectral computations.

The luminous efficiency data is in the form of a dict of `colour.colorimetry.spectrum.SpectralPowerDistribution` classes as follows:

    {'name': SpectralPowerDistribution, ..., 'name': SpectralPowerDistribution}

The following luminous efficiency functions are available:

- CIE 1924 Photopic Standard Observer [1]
- Judd Modified CIE 1951 Photopic Standard Observer [1]
- Judd-Vos Modified CIE 1978 Photopic Standard Observer [1]
- CIE 1964 Photopic 10 Degree Standard Observer [2]
- CIE 2008 2 Degree Physiologically Relevant LEF [3]
- CIE 2008 10 Degree Physiologically Relevant LEF [3]
- CIE 1951 Scotopic Standard Observer [1]

See also

Luminous Efficiency Functions IPython Notebook

Notes

- The luminous efficiency functions are provided at 1 nm steps.
- The mesopic luminous efficiency function is calculated using the CIE 1924 Photopic Standard Observer and CIE 1951 Scotopic Standard Observer luminous efficiency functions with the `colour.colorimetry.lefs.mesopic_luminous_efficiency_function()` definition and the data from `colour.colorimetry.dataset.lefs.MESOPIC_X_DATA` attribute that defines weighting factors dependent on the photopic luminance \(L_p\). [4]

References

[1] | (1, 2, 3, 4) http://www.cvrl.org/lumindex.htm (Last accessed 19 April 2014)

[2] | http://cvrl.ioo.ucl.ac.uk/cie.htm (Last accessed 24 February 2014)

[3] | (1, 2) http://www.cvrl.org/lumindex.htm (Last accessed 19 April 2014)

[4] | Mesopic Weighting Function (Last accessed 20 June 2014)

`colour.colorimetry.dataset.lefs.` `PHOTOPIC_LEFS` = CaseInsensitiveMapping({u'CIE 1924 Photopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8fd0>, u'CIE 1964 Photopic 10 Degree Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e060d0>, u'Judd-Vos Modified CIE 1978 Photopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06090>, u'cie_10_1964': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e060d0>, u'Judd Modified CIE 1951 Photopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06050>, u'CIE 2008 10 Degree Physiologically Relevant LEF': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06150>, u'CIE 2008 2 Degree Physiologically Relevant LEF': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06110>, u'cie_2_1924': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8fd0>})

  Photopic luminous efficiency functions.

  PHOTOPIC_LEFS : dict
    (‘CIE 1924 Photopic Standard Observer’, ‘Judd Modified CIE 1951 Photopic Standard Observer’, ‘Judd-Vos Modified CIE 1978 Photopic Standard Observer’, ‘CIE 1964 Photopic 10 Degree Standard Observer’, ‘CIE 2008 2 Degree Physiologically Relevant LEF’, ‘CIE 2008 10 Degree Physiologically Relevant LEF’)

  Aliases:

  - ‘cie_2_1924’: ‘CIE 1931 2 Degree Standard Observer’
  - ‘cie_10_1964’: ‘CIE 1964 Photopic 10 Degree Standard Observer’

`colour.colorimetry.dataset.lefs.` `SCOTOPIC_LEFS` = CaseInsensitiveMapping({u'cie_1951': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e061d0>, u'CIE 1951 Scotopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e061d0>})

  Scotopic luminous efficiency functions.

  SCOTOPIC_LEFS : dict
    (‘CIE 1951 Scotopic Standard Observer’,)

  Aliases:

  - ‘cie_1951’: ‘CIE 1951 Scotopic Standard Observer’

`colour.colorimetry.dataset.lefs.` `LEFS` = CaseInsensitiveMapping({u'CIE 1924 Photopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8fd0>, u'CIE 1964 Photopic 10 Degree Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e060d0>, u'cie_1951': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e061d0>, u'Judd-Vos Modified CIE 1978 Photopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06090>, u'cie_10_1964': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e060d0>, u'Judd Modified CIE 1951 Photopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06050>, u'CIE 1951 Scotopic Standard Observer': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e061d0>, u'CIE 2008 10 Degree Physiologically Relevant LEF': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06150>, u'CIE 2008 2 Degree Physiologically Relevant LEF': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102e06110>, u'cie_2_1924': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8fd0>})

  Aggregated luminous efficiency functions.

  LEFS : dict
    (‘CIE 1924 Photopic Standard Observer’, ‘Judd Modified CIE 1951 Photopic Standard Observer’, ‘Judd-Vos Modified CIE 1978 Photopic Standard Observer’, ‘CIE 1964 Photopic 10 Degree Standard Observer’, ‘CIE 2008 2 Degree Physiologically Relevant LEF’, ‘CIE 2008 10 Degree Physiologically Relevant LEF’, ‘CIE 1951 Scotopic Standard Observer’)

`colour.colorimetry.dataset.lefs.` `MESOPIC_X_DATA` = {1.0: CaseInsensitiveMapping({u'Red Heavy': CaseInsensitiveMapping({u'LRC': 1.0, u'MOVE': 0.68}), u'Blue Heavy': CaseInsensitiveMapping({u'LRC': 1.0, u'MOVE': 0.7})}), 10: CaseInsensitiveMapping({u'Red Heavy': CaseInsensitiveMapping({u'LRC': 1.0, u'MOVE': 0.98}), u'Blue Heavy': CaseInsensitiveMapping({u'LRC': 1.0, u'MOVE': 0.98})}), 0.1: CaseInsensitiveMapping({u'Red Heavy': CaseInsensitiveMapping({u'LRC': 0.11, u'MOVE': 0.34}), u'Blue Heavy': CaseInsensitiveMapping({u'LRC': 0.28, u'MOVE': 0.42})}), 0.01: CaseInsensitiveMapping({u'Red Heavy': CaseInsensitiveMapping({u'LRC': 0.01, u'MOVE': 0.0}), u'Blue Heavy': CaseInsensitiveMapping({u'LRC': 0.04, u'MOVE': 0.13})})}

  Weighting factors for the mesopic luminous efficiency function calculation.

  MESOPIC_X_DATA : dict